rnalysis.filtering.DESeqFilter.filter\_abs\_fold\_change
========================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: DESeqFilter.filter_abs_fold_change